==> cloud-5.0.0-rc2.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Vpc/VpcPeeringConnectionEditForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Vpc;

use Drupal\aws_cloud\Form\Ec2\AwsCloudContentForm;
use Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface;
use Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Service\CloudServiceInterface;
use Drupal\cloud\Service\EntityLinkRendererInterface;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Plugin\CachedDiscoveryClearerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the VPC peering connection entity edit forms.
 *
 * @ingroup aws_cloud
 */
class VpcPeeringConnectionEditForm extends AwsCloudContentForm {

  use CloudContentEntityTrait;

  /**
   * The AWS Cloud Operations service.
   *
   * @var \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface
   */
  protected $awsCloudOperationsService;

  /**
   * InternetGatewayEditForm constructor.
   *
   * @param \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface $aws_cloud_operations_service
   *   The AWS Cloud Operations service.
   * @param \Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface $ec2_service
   *   The AWS Cloud or OpenStack EC2 Service.
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The Messenger Service.
   * @param \Drupal\cloud\Service\EntityLinkRendererInterface $entity_link_renderer
   *   The entity link render service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The Entity Type Manager.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer
   *   A plugin cache clear instance.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The general renderer.
   * @param \Drupal\cloud\Service\CloudServiceInterface $cloud_service
   *   The Cloud service.
   */
  public function __construct(
    AwsCloudOperationsServiceInterface $aws_cloud_operations_service,
    Ec2ServiceInterface $ec2_service,
    EntityRepositoryInterface $entity_repository,
    EntityTypeBundleInfoInterface $entity_type_bundle_info,
    TimeInterface $time,
    Messenger $messenger,
    EntityLinkRendererInterface $entity_link_renderer,
    EntityTypeManagerInterface $entity_type_manager,
    CacheBackendInterface $cacheRender,
    CachedDiscoveryClearerInterface $plugin_cache_clearer,
    CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
    AccountInterface $current_user,
    RouteMatchInterface $route_match,
    DateFormatterInterface $date_formatter,
    RendererInterface $renderer,
    CloudServiceInterface $cloud_service
  ) {
    parent::__construct(
      $ec2_service,
      $entity_repository,
      $entity_type_bundle_info,
      $time,
      $messenger,
      $entity_link_renderer,
      $entity_type_manager,
      $cacheRender,
      $plugin_cache_clearer,
      $cloud_config_plugin_manager,
      $current_user,
      $route_match,
      $date_formatter,
      $renderer,
      $cloud_service
    );

    $this->awsCloudOperationsService = $aws_cloud_operations_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('aws_cloud.operations'),
      $container->get('aws_cloud.ec2'),
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('messenger'),
      $container->get('entity.link_renderer'),
      $container->get('entity_type.manager'),
      $container->get('cache.render'),
      $container->get('plugin.cache_clearer'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('current_user'),
      $container->get('current_route_match'),
      $container->get('date.formatter'),
      $container->get('renderer'),
      $container->get('cloud')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = '') {
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }
    $this->ec2Service->setCloudContext($entity->getCloudContext());

    $weight = -50;

    $form['vpc_peering_connection'] = [
      '#type'          => 'details',
      '#title'         => $this->t('VPC peering connection'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['vpc_peering_connection']['name'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Name'),
      '#maxlength'     => 255,
      '#size'          => 60,
      '#default_value' => $entity->label(),
      '#required'      => TRUE,
      '#weight'        => $weight++,
    ];

    $form['vpc_peering_connection']['vpc_peering_connection_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('VPC peering connection ID')),
      '#markup'        => $entity->getVpcPeeringConnectionId(),
    ];

    $form['vpc_peering_connection']['status_code'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Status Code')),
      '#markup'        => $entity->getStatusCode(),
    ];

    $form['vpc_peering_connection']['status_message'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Status Message')),
      '#markup'        => $entity->getStatusMessage(),
    ];

    $form['vpc_peering_connection']['created'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Created')),
      '#markup'        => $this->dateFormatter->format($entity->created(), 'short'),
    ];

    $form['requester'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Requester'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['requester']['requester_vpc_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getRequesterVpcId(),
      'aws_cloud_vpc',
      'vpc_id',
      ['#title' => $this->getItemTitle($this->t('Requester VPC ID'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['requester']['requester_cidr_block'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester CIDR Block')),
      '#markup'        => $entity->getRequesterCidrBlock(),
    ];

    $form['requester']['requester_account_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester AWS account ID')),
      '#markup'        => $entity->getRequesterAccountId(),
    ];

    $form['requester']['requester_region'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester Region')),
      '#markup'        => $entity->getRequesterRegion(),
    ];

    $form['accepter'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Accepter'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['accepter']['accepter_vpc_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getAccepterVpcId(),
      'aws_cloud_vpc',
      'vpc_id',
      ['#title' => $this->getItemTitle($this->t('Accepter VPC ID'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['accepter']['accepter_cidr_block'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter CIDR Block')),
      '#markup'        => $entity->getAccepterCidrBlock(),
    ];

    $form['accepter']['accepter_account_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter AWS account ID')),
      '#markup'        => $entity->getAccepterAccountId(),
    ];

    $form['accepter']['accepter_region'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter region')),
      '#markup'        => $entity->getAccepterRegion(),
    ];

    $form['fieldset_tags'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Tags'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['fieldset_tags'][] = $form['tags'];
    unset($form['tags']);

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    $form['actions'] = $this->actions($form, $form_state, $cloud_context);
    $form['actions']['#weight'] = $weight++;

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->awsCloudOperationsService->editVpcPeeringConnection($this->entity, $form, $form_state);
  }

}

==> cloud-5.1.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Vpc/VpcPeeringConnectionEditForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Vpc;

use Drupal\aws_cloud\Form\Ec2\AwsCloudContentForm;
use Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface;
use Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Service\CloudServiceInterface;
use Drupal\cloud\Service\EntityLinkRendererInterface;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Plugin\CachedDiscoveryClearerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the VPC peering connection entity edit forms.
 *
 * @ingroup aws_cloud
 */
class VpcPeeringConnectionEditForm extends AwsCloudContentForm {

  use CloudContentEntityTrait;

  /**
   * The AWS Cloud Operations service.
   *
   * @var \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface
   */
  protected $awsCloudOperationsService;

  /**
   * InternetGatewayEditForm constructor.
   *
   * @param \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface $aws_cloud_operations_service
   *   The AWS Cloud Operations service.
   * @param \Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface $ec2_service
   *   The AWS Cloud or OpenStack EC2 Service.
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The Messenger Service.
   * @param \Drupal\cloud\Service\EntityLinkRendererInterface $entity_link_renderer
   *   The entity link render service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer
   *   A plugin cache clear instance.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The general renderer.
   * @param \Drupal\cloud\Service\CloudServiceInterface $cloud_service
   *   The Cloud service.
   */
  public function __construct(
    AwsCloudOperationsServiceInterface $aws_cloud_operations_service,
    Ec2ServiceInterface $ec2_service,
    EntityRepositoryInterface $entity_repository,
    EntityTypeBundleInfoInterface $entity_type_bundle_info,
    TimeInterface $time,
    Messenger $messenger,
    EntityLinkRendererInterface $entity_link_renderer,
    EntityTypeManagerInterface $entity_type_manager,
    CacheBackendInterface $cacheRender,
    CachedDiscoveryClearerInterface $plugin_cache_clearer,
    CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
    AccountInterface $current_user,
    RouteMatchInterface $route_match,
    DateFormatterInterface $date_formatter,
    RendererInterface $renderer,
    CloudServiceInterface $cloud_service
  ) {
    parent::__construct(
      $ec2_service,
      $entity_repository,
      $entity_type_bundle_info,
      $time,
      $messenger,
      $entity_link_renderer,
      $entity_type_manager,
      $cacheRender,
      $plugin_cache_clearer,
      $cloud_config_plugin_manager,
      $current_user,
      $route_match,
      $date_formatter,
      $renderer,
      $cloud_service
    );

    $this->awsCloudOperationsService = $aws_cloud_operations_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('aws_cloud.operations'),
      $container->get('aws_cloud.ec2'),
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('messenger'),
      $container->get('entity.link_renderer'),
      $container->get('entity_type.manager'),
      $container->get('cache.render'),
      $container->get('plugin.cache_clearer'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('current_user'),
      $container->get('current_route_match'),
      $container->get('date.formatter'),
      $container->get('renderer'),
      $container->get('cloud')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = '') {
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }
    $this->ec2Service->setCloudContext($entity->getCloudContext());

    $weight = -50;

    $form['vpc_peering_connection'] = [
      '#type'          => 'details',
      '#title'         => $this->t('VPC peering connection'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['vpc_peering_connection']['name'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Name'),
      '#maxlength'     => 255,
      '#size'          => 60,
      '#default_value' => $entity->label(),
      '#required'      => TRUE,
      '#weight'        => $weight++,
    ];

    $form['vpc_peering_connection']['vpc_peering_connection_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('VPC peering connection ID')),
      '#markup'        => $entity->getVpcPeeringConnectionId(),
    ];

    $form['vpc_peering_connection']['status_code'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Status Code')),
      '#markup'        => $entity->getStatusCode(),
    ];

    $form['vpc_peering_connection']['status_message'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Status Message')),
      '#markup'        => $entity->getStatusMessage(),
    ];

    $form['vpc_peering_connection']['created'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Created')),
      '#markup'        => $this->dateFormatter->format($entity->created(), 'short'),
    ];

    $form['requester'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Requester'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['requester']['requester_vpc_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getRequesterVpcId(),
      'aws_cloud_vpc',
      'vpc_id',
      ['#title' => $this->getItemTitle($this->t('Requester VPC ID'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['requester']['requester_cidr_block'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester CIDR Block')),
      '#markup'        => $entity->getRequesterCidrBlock(),
    ];

    $form['requester']['requester_account_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester AWS account ID')),
      '#markup'        => $entity->getRequesterAccountId(),
    ];

    $form['requester']['requester_region'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Requester region')),
      '#markup'        => $entity->getRequesterRegion(),
    ];

    $form['accepter'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Accepter'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['accepter']['accepter_vpc_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getAccepterVpcId(),
      'aws_cloud_vpc',
      'vpc_id',
      ['#title' => $this->getItemTitle($this->t('Accepter VPC ID'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['accepter']['accepter_cidr_block'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter CIDR Block')),
      '#markup'        => $entity->getAccepterCidrBlock(),
    ];

    $form['accepter']['accepter_account_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter AWS account ID')),
      '#markup'        => $entity->getAccepterAccountId(),
    ];

    $form['accepter']['accepter_region'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Accepter region')),
      '#markup'        => $entity->getAccepterRegion(),
    ];

    $form['fieldset_tags'] = [
      '#type'          => 'details',
      '#title'         => $this->t('Tags'),
      '#open'          => TRUE,
      '#weight'        => $weight++,
    ];

    $form['fieldset_tags'][] = $form['tags'];
    unset($form['tags']);

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    $form['actions'] = $this->actions($form, $form_state, $cloud_context);
    $form['actions']['#weight'] = $weight++;

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->awsCloudOperationsService->editVpcPeeringConnection($this->entity, $form, $form_state);
  }

}
